CREATE DOMAIN ADRES_IP_D AS VARCHAR(15) CHARACTER SET WIN1250 DEFAULT '0.0.0.0' COLLATE WIN1250;
CREATE DOMAIN ADRES_EMAIL_D AS VARCHAR(64) CHARACTER SET WIN1250 COLLATE WIN1250;
CREATE DOMAIN KONTO_WWW_TYP_D AS SMALLINT NOT NULL CHECK (VALUE IN (0,1,2));
CREATE DOMAIN FILE_EXT_D AS VARCHAR(4) CHARACTER SET WIN1250 COLLATE WIN1250;
CREATE DOMAIN WWW_INSTALACJA_D AS
VARCHAR(30) CHARACTER SET WIN1250
COLLATE WIN1250;

CREATE EXCEPTION WWW_SPOSOBY_DOSTAWY_BD_EXC 'Nie mona usun tego sposobu dostawy';


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE GENERATOR WWW_USERS_ID_GEN;

CREATE TABLE WWW_USERS (
    ID                INTEGER NOT NULL,
    HASLO             VARCHAR(64),
    LOGIN             VARCHAR(60) NOT NULL,
    CONTACT_ID        INTEGER NOT NULL,
    PERSON_ID         SMALLINT,
    PRACOWNIK_ID      INTEGER DEFAULT 0,
    AD_USER_ID        INTEGER DEFAULT 0,
    OPERATOR_NAZWA    STRING15_D /* STRING15_D = VARCHAR(15) */,
    MALPKA            BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    TYP               KONTO_WWW_TYP_D DEFAULT 0 NOT NULL /* KONTO_WWW_TYP_D = SMALLINT NOT NULL CHECK (VALUE IN (0,1,2)) */,
    PRAWA             SMALLINT,
    REG_DATE          TIMESTAMP,
    LAST_LOGIN_DATE   TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    LAST_LOGIN_FROM   STRING60_D /* STRING60_D = VARCHAR(60) */,
    WYLACZONE         BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    POWOD_WYLACZENIA  STRING250_D /* STRING250_D = VARCHAR(250) */,
    NEWSLETTER        BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    LICZBA_LOGOWAN    INTEGER DEFAULT 0,
    FIRMA             BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    PROFIL_ID         INTEGER,
    HASH              STRING10_D COLLATE PXW_PLK /* STRING10_D = VARCHAR(10) */,
    ZW                BOOLEAN_D DEFAULT 0 /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL */
);


/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_LOGIN_UK UNIQUE (LOGIN);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_CONTACT_ID_FK FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PERSON_ID_FK FOREIGN KEY (PERSON_ID) REFERENCES R3_PERSONS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PRACOWNIK_ID_FK FOREIGN KEY (PRACOWNIK_ID) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
--ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PROFIL_ID_FK FOREIGN KEY (PROFIL_ID) REFERENCES WWW_PROFILE (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_USERS_AD_USER_ID_IND ON WWW_USERS (AD_USER_ID);
CREATE INDEX WWW_USERS_DATY_IND ON WWW_USERS (REG_DATE, LAST_LOGIN_DATE, LAST_LOGIN_FROM);
CREATE INDEX WWW_USERS_LOGIN_IND ON WWW_USERS (LOGIN);
CREATE INDEX WWW_USERS_NEWSLETTER_IND ON WWW_USERS (NEWSLETTER);
CREATE INDEX WWW_USERS_OP_NAZWA_IND ON WWW_USERS (OPERATOR_NAZWA);
CREATE INDEX WWW_USERS_TYP_IND ON WWW_USERS (TYP);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_USERS_BI0 */
CREATE TRIGGER WWW_USERS_BI0 FOR WWW_USERS
ACTIVE BEFORE INSERT POSITION 0
AS
begin
  /* Trigger text */
  if(new.id is NULL) then new.id = gen_id(WWW_USERS_ID_GEN, 1);
end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_USERS TO WWW_ROLE;

INSERT INTO WWW_USERS (ID,HASLO,LOGIN,CONTACT_ID,PERSON_ID,PRACOWNIK_ID,AD_USER_ID,OPERATOR_NAZWA,MALPKA,TYP,PRAWA,REG_DATE,LAST_LOGIN_DATE,LAST_LOGIN_FROM,WYLACZONE,POWOD_WYLACZENIA,NEWSLETTER,LICZBA_LOGOWAN,FIRMA) VALUES (0,'','Brak',0,0,NULL,NULL,NULL,0,0,0,NULL,'12-OCT-2007 15:26:00',NULL,1,'To konto nie suy do logowania',0,NULL,0);




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_USERS_CONFIG (
    USER_ID          INTEGER,
    MAGAZYN_ID       INTEGER,
    STAN_TOWARU_MAG  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    NA_STRONIE       INTEGER,
    SZABLON          STRING200_D /* STRING200_D = VARCHAR(200) */,
    ZK_DOC_ID        INTEGER
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_USERS_CONFIG ADD CONSTRAINT WWW_USERS_CONFIG_MAGAZYN_FK FOREIGN KEY (MAGAZYN_ID) REFERENCES GM_MAGAZYNY (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_USERS_CONFIG ADD CONSTRAINT WWW_USERS_CONFIG_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_USERS_CONFIG ADD CONSTRAINT WWW_USERS_CONFIG_ZK_DOC_ID_FK FOREIGN KEY (ZK_DOC_ID) REFERENCES GM_KODY (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_USERS_CONFIG TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_DB_VERSION (
    VERSION_NUMBER  INTEGER NOT NULL,
    UPGRADE_DATE    DATE DEFAULT current_date NOT NULL,
    OPERATOR        VARCHAR(20)
);




/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_DB_VERSION TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_CONFIG_ID_GEN;

CREATE TABLE WWW_CONFIG (
    ID          INTEGER NOT NULL,
    GRUPA       VARCHAR(64) NOT NULL,
    KLUCZ       VARCHAR(64) NOT NULL,
    WARTOSC     VARCHAR(200),
    CDATE       TIMESTAMP,
    MDATE       TIMESTAMP,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_CONFIG ADD CONSTRAINT WWW_CONFIG_UNQ UNIQUE (INSTALACJA, GRUPA, KLUCZ);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_CONFIG ADD CONSTRAINT WWW_CONFIG_ID_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_CONFIG_DATY_IND ON WWW_CONFIG (CDATE, MDATE);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_CONFIG_BI */
CREATE TRIGGER WWW_CONFIG_BI FOR WWW_CONFIG
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_CONFIG_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_CONFIG TO WWW_ROLE WITH GRANT OPTION;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_ERRORS_ID_GEN;

CREATE TABLE WWW_ERRORS (
    ID        INTEGER NOT NULL,
    NUMER     INTEGER,
    SCIEZKA   VARCHAR(256),
    PLIK      VARCHAR(32),
    LINIA     INTEGER,
    STR       VARCHAR(512),
    OPIS      BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    DATA      TIMESTAMP,
    ADRES_IP  ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    USER_ID   INTEGER
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ERRORS ADD CONSTRAINT WWW_ERRORS_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ERRORS_ADRES_IP_IND ON WWW_ERRORS (ADRES_IP);
CREATE INDEX WWW_ERRORS_DATA_IND ON WWW_ERRORS (DATA);
CREATE INDEX WWW_ERRORS_NUMER_IND ON WWW_ERRORS (NUMER);
CREATE INDEX WWW_ERRORS_PLIK_IND ON WWW_ERRORS (PLIK);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_ERRORS_BI */
CREATE TRIGGER WWW_ERRORS_BI FOR WWW_ERRORS
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_ERRORS_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ERRORS TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_FAV_ID_GEN;

CREATE TABLE WWW_FAV (
    ID         INTEGER NOT NULL,
    USER_ID    INTEGER NOT NULL,
    NAZWA      VARCHAR(50),
    ILOSC_POZ  SMALLINT DEFAULT 0,
    DOMYSLNY   BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE      TIMESTAMP,
    MDATE      TIMESTAMP
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_FAV ADD CONSTRAINT WWW_FAV_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_FAV ADD CONSTRAINT WWW_FAV_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_FAV_NAZWA_IND ON WWW_FAV (NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_FAV_AI0 */
CREATE TRIGGER WWW_FAV_AI0 FOR WWW_FAV
ACTIVE AFTER INSERT POSITION 0
AS
begin
     if( NEW.domyslny = 1 ) then begin
        UPDATE WWW_FAV SET DOMYSLNY = 0 WHERE USER_ID = NEW.USER_ID AND ID != NEW.ID;
    end
end
^


/* Trigger: WWW_FAV_AU0 */
CREATE TRIGGER WWW_FAV_AU0 FOR WWW_FAV
ACTIVE AFTER UPDATE POSITION 0
AS
begin
  if( NEW.domyslny = 1 ) then begin
        UPDATE WWW_FAV SET DOMYSLNY = 0 WHERE USER_ID = NEW.USER_ID AND ID != NEW.ID;
  end
end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_FAV TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_FAV_POZ (
    FAV_ID       INTEGER NOT NULL,
    TOWAR_ID     INTEGER NOT NULL,
    TOWAR_NAZWA  NAZWA_D NOT NULL COLLATE WIN1250 /* NAZWA_D = VARCHAR(250) NOT NULL */,
    INFO_CENA    BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    INFO_STAN    BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    INFO_EMAIL   BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    INFO_SMS     BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE        TIMESTAMP,
    MDATE        TIMESTAMP
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_FAV_POZ ADD CONSTRAINT WWW_FAV_POZ_PK PRIMARY KEY (FAV_ID, TOWAR_ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_FAV_POZ ADD CONSTRAINT WWW_FAV_POZ_FAV_ID_FK FOREIGN KEY (FAV_ID) REFERENCES WWW_FAV (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_FAV_POZ_TOWAR_NAZWA_IND ON WWW_FAV_POZ (TOWAR_NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_FAV_POZ TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/






CREATE TABLE WWW_GRUPYT (
    ID          INTEGER NOT NULL,
    ID_PARENT   INTEGER,
    NAZWA       VARCHAR(50) NOT NULL,
    IMAGE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    IMG         VARCHAR(250),
    PHOTO       BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    PHOTO_FILE  VARCHAR(250),
    OPIS        BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT ADD CONSTRAINT WWW_GRUPYT_ID_INSTALACJA_UNQ UNIQUE (ID, INSTALACJA);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT ADD CONSTRAINT WWW_GRUPYT_ID_FK FOREIGN KEY (ID) REFERENCES GM_GRUPYT (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_GRUPYT_ID_PARENT_IND ON WWW_GRUPYT (ID_PARENT);
CREATE INDEX WWW_GRUPYT_INSTALACJA_IND ON WWW_GRUPYT (INSTALACJA);
CREATE INDEX WWW_GRUPYT_NAZWA_IND ON WWW_GRUPYT (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_GRUPYT TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_GRUPYT_EXT (
    ID          INTEGER NOT NULL,
    ID_PARENT   INTEGER,
    NAZWA       VARCHAR(50) NOT NULL,
    IMAGE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    IMG         VARCHAR(250),
    PHOTO       BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    PHOTO_FILE  VARCHAR(250),
    OPIS        BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT_EXT ADD CONSTRAINT WWW_GRUPYT_EXT_ID_INSTAL_UNQ UNIQUE (ID, INSTALACJA);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT_EXT ADD CONSTRAINT WWW_GRUPYT_EXT_ID_FK FOREIGN KEY (ID) REFERENCES GM_GRUPYT_EXT (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_GRUPYT_EXT_ID_PARENT_IND ON WWW_GRUPYT_EXT (ID_PARENT);
CREATE INDEX WWW_GRUPYT_EXT_INSTALACJA_IND ON WWW_GRUPYT_EXT (INSTALACJA);
CREATE INDEX WWW_GRUPYT_EXT_NAZWA_IND ON WWW_GRUPYT_EXT (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_GRUPYT_EXT TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_KOMENTARZE_ID_GEN;


CREATE TABLE WWW_KOMENTARZE (
    ID           INTEGER NOT NULL,
    TOWAR_ID     INTEGER,
    TOWAR_NAZWA  VARCHAR(250),
    TOWAR_SKROT  VARCHAR(25),
    USER_ID      INTEGER,
    USER_NAME    VARCHAR(50),
    TRESC        BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    OCENA        SMALLINT,
    DATA         DATE,
    ADRES_IP     ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    INSTALACJA   WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOMENTARZE ADD CONSTRAINT WWW_KOMENTARZE_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOMENTARZE ADD CONSTRAINT WWW_KOMENTARZE_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_KOMENTARZE_ADRES_IP_IND ON WWW_KOMENTARZE (ADRES_IP);
CREATE INDEX WWW_KOMENTARZE_DATA_IND ON WWW_KOMENTARZE (DATA);
CREATE INDEX WWW_KOMENTARZE_INSTALACJA_IND ON WWW_KOMENTARZE (INSTALACJA);
CREATE INDEX WWW_KOMENTARZE_OCENA_IND ON WWW_KOMENTARZE (OCENA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_KOMENTARZE TO WWW_ROLE;
/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_KOSZYK_ID_GEN;

CREATE TABLE WWW_KOSZYK (
    ID           INTEGER NOT NULL,
    USER_ID      INTEGER,
    NAZWA        VARCHAR(16),
    DOMYSLNY     BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE        TIMESTAMP,
    MDATE        TIMESTAMP,
    CONTACT_ID   INTEGER,
    ODBIORCA_ID  INTEGER,
    PLATNIK_ID   INTEGER,
    CENA_ID      INTEGER,
    WALUTA       INTEGER,
    RABAT_ID     INTEGER,
    RABAT        PROCENT_D /* PROCENT_D = NUMERIC(6,2) DEFAULT 0 CHECK  ((VALUE >=0) OR (VALUE IS NULL)) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOSZYK ADD CONSTRAINT WWW_KOSZYK_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOSZYK ADD CONSTRAINT WWW_KOSZYK_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_KOSZYK_DATY_IND ON WWW_KOSZYK (CDATE, MDATE);
CREATE INDEX WWW_KOSZYK_DOMYSLNY_IND ON WWW_KOSZYK (DOMYSLNY);
CREATE INDEX WWW_KOSZYK_NAZWA_IND ON WWW_KOSZYK (NAZWA);
CREATE UNIQUE INDEX WWW_KOSZYK_USER_NAZWA_UK ON WWW_KOSZYK (USER_ID, NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_KOSZYK_AI0 */
CREATE TRIGGER WWW_KOSZYK_AI0 FOR WWW_KOSZYK
ACTIVE AFTER INSERT POSITION 0
AS
begin
/* Trigger text */
    if( NEW.domyslny = 1 ) then begin
        UPDATE WWW_KOSZYK SET DOMYSLNY = 0 WHERE USER_ID = NEW.USER_ID AND ID != NEW.ID;
    end
end
^


/* Trigger: WWW_KOSZYK_AU0 */
CREATE TRIGGER WWW_KOSZYK_AU0 FOR WWW_KOSZYK
ACTIVE AFTER UPDATE POSITION 0
AS
begin
/* Trigger text */
    if( NEW.domyslny = 1 ) then begin
        UPDATE WWW_KOSZYK SET DOMYSLNY = 0 WHERE USER_ID = NEW.USER_ID AND ID != NEW.ID;
    end
end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_KOSZYK TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_KOSZYK_POZ (
    KOSZYK_ID  INTEGER NOT NULL,
    TOWAR_ID   INTEGER NOT NULL,
    ILOSC      ILOSC_D NOT NULL /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    OPK_ID     INTEGER,
    OPK_ILOSC  ILOSC_D NOT NULL /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_ID    SMALLINT,
    WALUTA     INTEGER,
    CENA       WARTOSC_D NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    CENAB      WARTOSC_D DEFAULT 0 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    CENA_WAL   CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENAB_WAL  CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    RABAT_ID   INTEGER,
    RABAT      SMALLINT,
    UWAGI      BLOB SUB_TYPE 1 SEGMENT SIZE 80
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOSZYK_POZ ADD CONSTRAINT WWW_KOSZYK_POZ_PK PRIMARY KEY (KOSZYK_ID, TOWAR_ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KOSZYK_POZ ADD CONSTRAINT WWW_KOSZYK_KOSZYK_ID_FK FOREIGN KEY (KOSZYK_ID) REFERENCES WWW_KOSZYK (ID) ON DELETE CASCADE;


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_KOSZYK_POZ TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_LOG_ID_GEN;

CREATE TABLE WWW_LOG (
    ID        INTEGER NOT NULL,
    NUMER     INTEGER,
    SCIEZKA   VARCHAR(1024),
    PLIK      VARCHAR(128),
    LINIA     INTEGER,
    STR       VARCHAR(512),
    OPIS      BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    DATA      TIMESTAMP,
    ADRES_IP  ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    USER_ID   INTEGER
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_LOG ADD CONSTRAINT WWW_LOG_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_LOG_ADRES_IP_IND ON WWW_LOG (ADRES_IP);
CREATE INDEX WWW_LOG_DATA_IND ON WWW_LOG (DATA);
CREATE INDEX WWW_LOG_NUMER_IND ON WWW_LOG (NUMER);
CREATE INDEX WWW_LOG_PLIK_IND ON WWW_LOG (PLIK);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_LOG_BI */
CREATE TRIGGER WWW_LOG_BI FOR WWW_LOG
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_LOG_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_LOG TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/




CREATE TABLE WWW_ONLINE (
    USER_ID      INTEGER DEFAULT 0 NOT NULL,
    SESSION_ID   CHAR(32) NOT NULL,
    FIRST_VISIT  TIMESTAMP,
    LAST_ACTIVE  TIMESTAMP,
    ADRES_IP     ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    USER_AGENT   VARCHAR(200),
    WEJSCIE_ID   INTEGER
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_ONLINE ADD CONSTRAINT WWW_ONLINE_SESSION_ID_UNQ UNIQUE (SESSION_ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ONLINE ADD CONSTRAINT WWW_ONLINE_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ONLINE_ADRES_IP_IND ON WWW_ONLINE (ADRES_IP);
CREATE INDEX WWW_ONLINE_LAST_ACTIVE_IND ON WWW_ONLINE (LAST_ACTIVE);



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ONLINE TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SPOSOBY_DOSTAWY_ID_GEN;

CREATE TABLE WWW_SPOSOBY_DOSTAWY (
    ID          INTEGER NOT NULL,
    NAZWA       VARCHAR(60),
    USLUGA      INTEGER DEFAULT NULL,
    DOMYSLNY    BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    WYSWIETLAJ  BOOLEAN_D DEFAULT 1 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    OPIS        STRING250_D /* STRING250_D = VARCHAR(250) */,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SPOSOBY_DOSTAWY ADD CONSTRAINT WWW_SPOSOBY_DOSTAWY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SPOSOBY_DOSTAWY ADD CONSTRAINT WWW_SPOSOBY_DOSTAWY_USLUGA_FK FOREIGN KEY (USLUGA) REFERENCES GM_TOWARY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SPOSOBY_DOSTAWY_INSTAL_IND ON WWW_SPOSOBY_DOSTAWY (INSTALACJA);
CREATE INDEX WWW_SPOSOBY_DOSTAWY_NAZWA_IND ON WWW_SPOSOBY_DOSTAWY (NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SPOSOBY_DOSTAWY_BD0 */
CREATE TRIGGER WWW_SPOSOBY_DOSTAWY_BD0 FOR WWW_SPOSOBY_DOSTAWY
ACTIVE BEFORE DELETE POSITION 0
AS
begin
  /* Trigger text */
  if  (old.id < 2) then EXCEPTION WWW_SPOSOBY_DOSTAWY_BD_EXC;
end
^


/* Trigger: WWW_SPOSOBY_DOSTAWY_BI */
CREATE TRIGGER WWW_SPOSOBY_DOSTAWY_BI FOR WWW_SPOSOBY_DOSTAWY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN NEW.ID = GEN_ID(WWW_SPOSOBY_DOSTAWY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SPOSOBY_DOSTAWY TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE GENERATOR WWW_POWIADOMIENIA_ID_GEN;

CREATE TABLE WWW_POWIADOMIENIA (
    ID           INTEGER NOT NULL,
    MAGAZYN_ID   INTEGER DEFAULT 0,
    "EVENT"      SMALLINT DEFAULT 0 NOT NULL,
    TYP          INTEGER DEFAULT 0 NOT NULL,
    ADRES        STRING100_D /* STRING100_D = VARCHAR(100) */ COLLATE WIN1250,
    CALENDAR_ID  INTEGER DEFAULT 0,
    MODUL        SMALLINT DEFAULT -1,
    INSTALACJA   WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_POWIADOMIENIA ADD CONSTRAINT WWW_POWIADOMIENIA_ID_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_POWIADOMIENIA ADD CONSTRAINT WWW_POWIADOMIENIA_CALENDAR_FK FOREIGN KEY (CALENDAR_ID) REFERENCES CRM_CALENDARS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_POWIADOMIENIA_INSTAL_IND ON WWW_POWIADOMIENIA (INSTALACJA);
CREATE INDEX WWW_POWIADOMIENIA_MAIN_IND ON WWW_POWIADOMIENIA (ADRES, "EVENT", TYP);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_POWIADOMIENIA_BI */
CREATE TRIGGER WWW_POWIADOMIENIA_BI FOR WWW_POWIADOMIENIA
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_POWIADOMIENIA_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_POWIADOMIENIA TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PRZESYLKI_ID_GEN;

CREATE TABLE WWW_PRZESYLKI (
    ID              INTEGER NOT NULL,
    SP_DOST_ID      INTEGER NOT NULL,
    NUM             SMALLINT NOT NULL,
    NAZWA           VARCHAR(25) NOT NULL,
    KOSZT           CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    GRATIS_KWOTA    CENAN_D NOT NULL /* CENAN_D = NUMERIC(15,4) NOT NULL */,
    POBRANIE        BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    POBRANIE_KOSZT  CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    OPIS            STRING250_D /* STRING250_D = VARCHAR(250) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI ADD CONSTRAINT WWW_PRZESYLKI_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI ADD CONSTRAINT WWW_PRZESYLKI_SP_DOST_FK FOREIGN KEY (SP_DOST_ID) REFERENCES WWW_SPOSOBY_DOSTAWY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_PRZESYLKI_NAZWA_IND ON WWW_PRZESYLKI (NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PRZESYLKI_BI */
CREATE TRIGGER WWW_PRZESYLKI_BI FOR WWW_PRZESYLKI
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PRZESYLKI_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PRZESYLKI TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_PRZESYLKI_KOSZTY (
    PRZESYLKA_ID  INTEGER NOT NULL,
    NUM           SMALLINT NOT NULL,
    WAGA_OD       INTEGER NOT NULL,
    WAGA_DO       INTEGER NOT NULL,
    KOSZT         CENAN_D NOT NULL /* CENAN_D = NUMERIC(15,4) NOT NULL */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI_KOSZTY ADD CONSTRAINT WWW_PRZESYLKI_KOSZTY_UNQ UNIQUE (PRZESYLKA_ID, NUM);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI_KOSZTY ADD CONSTRAINT WWW_PRZESYLKIK_PRZESYL_FK FOREIGN KEY (PRZESYLKA_ID) REFERENCES WWW_PRZESYLKI (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_PRZESYLKIK_WAGA_DO_IND ON WWW_PRZESYLKI_KOSZTY (WAGA_DO);
CREATE INDEX WWW_PRZESYLKIK_WAGA_OD_IND ON WWW_PRZESYLKI_KOSZTY (WAGA_OD);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PRZESYLKI_KOSZTY TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_PRZESYLKI_OPCJE (
    PRZESYLKA_ID  INTEGER NOT NULL,
    NUM           SMALLINT NOT NULL,
    GRUPA         STRING10_D /* STRING10_D = VARCHAR(10) */,
    NAZWA         STRING30_D NOT NULL /* STRING30_D = VARCHAR(30) */,
    KOSZT         CENAN_D NOT NULL /* CENAN_D = NUMERIC(15,4) NOT NULL */,
    OPIS          STRING250_D /* STRING250_D = VARCHAR(250) */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI_OPCJE ADD CONSTRAINT WWW_PRZESYLKIO_PRZESYL_NUM_UNQ UNIQUE (PRZESYLKA_ID, NUM);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PRZESYLKI_OPCJE ADD CONSTRAINT WWW_PRZESYLKIO_PRZESYL_FK FOREIGN KEY (PRZESYLKA_ID) REFERENCES WWW_PRZESYLKI (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_PRZESYLKIO_NAZWA_IND ON WWW_PRZESYLKI_OPCJE (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PRZESYLKI_OPCJE TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_REG_ID_GEN;

CREATE TABLE WWW_REG (
    ID           INTEGER NOT NULL,
    GUID         GUID_D NOT NULL /* GUID_D = CHAR(36) */,
    IMIE         STRING30_D /* STRING30_D = VARCHAR(30) */,
    NAZWISKO     STRING30_D /* STRING30_D = VARCHAR(30) */,
    TELEFON      STRING20_D /* STRING20_D = VARCHAR(20) */,
    EMAIL        STRING60_D /* STRING60_D = VARCHAR(60) */,
    HASLO        STRING20_D /* STRING20_D = VARCHAR(20) */,
    FIRMA        BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    FIRMA_NAZWA  STRING200_D /* STRING200_D = VARCHAR(200) */,
    NIP          STRING20_D /* STRING20_D = VARCHAR(20) */,
    PLATNIK_VAT  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CONTACT_ID   INTEGER DEFAULT 0,
    KOD          STRING10_D /* STRING10_D = VARCHAR(10) */,
    MIEJSCOWOSC  STRING50_D /* STRING50_D = VARCHAR(50) */,
    ULICA        STRING50_D /* STRING50_D = VARCHAR(50) */,
    DOM          STRING10_D /* STRING10_D = VARCHAR(10) */,
    LOKAL        STRING10_D /* STRING10_D = VARCHAR(10) */,
    ZGODA        BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ZASADY       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ADRES_IP     ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    REG_DATE     TIMESTAMP,
    REGON        STRING20_D COLLATE PXW_PLK /* STRING20_D = VARCHAR(20) */,
    DOCS         BLOB SUB_TYPE 1 SEGMENT SIZE 512
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_REG ADD CONSTRAINT WWW_REG_GUID_UK UNIQUE (GUID);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_REG ADD CONSTRAINT WWW_REG_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_REG_BI */
CREATE TRIGGER WWW_REG_BI FOR WWW_REG
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_REG_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_REG TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SEARCH_HISTORY_ID_GEN;

CREATE TABLE WWW_SEARCH_HISTORY (
    ID             INTEGER NOT NULL,
    WORD           VARCHAR(84) NOT NULL COLLATE PXW_PLK,
    SEARCH_COUNT   INTEGER NOT NULL,
    FIRST_SEARCH   TIMESTAMP NOT NULL,
    LAST_SEARCH    TIMESTAMP NOT NULL,
    SEARCH_RESULT  BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SEARCH_HISTORY ADD CONSTRAINT WWW_SEARCH_HISTORY_PK PRIMARY KEY (ID);

/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SEARCH_HISTORY_DATY_IND ON WWW_SEARCH_HISTORY (FIRST_SEARCH, LAST_SEARCH);
CREATE UNIQUE INDEX WWW_SEARCH_HISTORY_WYRAZ_UK ON WWW_SEARCH_HISTORY (WORD);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SEARCH_HISTORY_BI */
CREATE TRIGGER WWW_SEARCH_HISTORY_BI FOR WWW_SEARCH_HISTORY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SEARCH_HISTORY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SEARCH_HISTORY TO WWW_ROLE;





/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_STANY_UMOWNE_ID_GEN;

CREATE TABLE WWW_STANY_UMOWNE (
    ID            INTEGER NOT NULL,
    NAZWA         VARCHAR(20) NOT NULL,
    RZECZYWISTY   BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    PROG_DOLNY    ILOSC_NULL_D /* ILOSC_NULL_D = NUMERIC(15,4) DEFAULT 0 CHECK  (VALUE >=0 OR VALUE IS NULL) */,
    PROG_GORNY    ILOSC_NULL_D /* ILOSC_NULL_D = NUMERIC(15,4) DEFAULT 0 CHECK  (VALUE >=0 OR VALUE IS NULL) */,
    GRUPA_ID      INTEGER DEFAULT 0 NOT NULL,
    GRUPA_EXT_ID  SMALLINT,
    TOWAR_ID      INTEGER DEFAULT 0 NOT NULL,
    ICO           BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ICO_NAME      VARCHAR(128),
    ICO_EXT       VARCHAR(4),
    ICO_WIDTH     SMALLINT,
    ICO_HEIGHT    SMALLINT
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_STANY_UMOWNE ADD CONSTRAINT WWW_STANY_UMOWNE_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_STANY_UMOWNE_PD_IND ON WWW_STANY_UMOWNE (PROG_DOLNY);
CREATE INDEX WWW_STANY_UMOWNE_PG_IND ON WWW_STANY_UMOWNE (PROG_GORNY);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_STANY_UMOWNE_BI */
CREATE TRIGGER WWW_STANY_UMOWNE_BI FOR WWW_STANY_UMOWNE
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_STANY_UMOWNE_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_STANY_UMOWNE TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_STATS (
    TOWAR_ID    INTEGER NOT NULL,
    WYSWIETLEN  INTEGER NOT NULL,
    DATA        DATE NOT NULL,
    ROK         SMALLINT NOT NULL,
    MIESIAC     SMALLINT NOT NULL,
    DZIEN       SMALLINT NOT NULL
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_STATS ADD CONSTRAINT WWW_STATS_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_STATS_DATA_IND ON WWW_STATS (DATA);
CREATE INDEX WWW_STATS_GLOWNY_IND ON WWW_STATS (TOWAR_ID, ROK, MIESIAC, DZIEN);
CREATE INDEX WWW_STATS_WYSWIETLEN_IND ON WWW_STATS (WYSWIETLEN);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_STATS TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_WYRAZY_ID_GEN;

CREATE TABLE WWW_WYRAZY (
    ID     INTEGER NOT NULL,
    WYRAZ  VARCHAR(64) NOT NULL COLLATE PXW_PLK,
    CDATE  TIMESTAMP,
    MDATE  TIMESTAMP
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_WYRAZY ADD CONSTRAINT WWW_WYRAZY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_WYRAZY_DATY_IND ON WWW_WYRAZY (CDATE, MDATE);
CREATE INDEX WWW_WYRAZY_WYRAZ_IND ON WWW_WYRAZY (WYRAZ);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_WYRAZY_BI */
CREATE TRIGGER WWW_WYRAZY_BI FOR WWW_WYRAZY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_WYRAZY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_WYRAZY TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SYNONIMY_ID_GEN;

CREATE TABLE WWW_SYNONIMY (
    ID        INTEGER NOT NULL,
    WYRAZ_ID  INTEGER NOT NULL,
    SYNONIM   VARCHAR(64) NOT NULL COLLATE PXW_PLK
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SYNONIMY ADD CONSTRAINT WWW_SYNONIMY_PK PRIMARY KEY (ID);

/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SYNONIMY ADD CONSTRAINT WWW_SYNONIMY_WYRAZ_ID_FK FOREIGN KEY (WYRAZ_ID) REFERENCES WWW_WYRAZY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE UNIQUE INDEX WWW_SYNONIMY_WYRAZ_SYNONIM_UK ON WWW_SYNONIMY (WYRAZ_ID, SYNONIM);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SYNONIMY_BI */
CREATE TRIGGER WWW_SYNONIMY_BI FOR WWW_SYNONIMY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SYNONIMY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SYNONIMY TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_TOWARY (
    TOWAR_ID  INTEGER NOT NULL,
    NAZWA     VARCHAR(250) NOT NULL,
    OPIS      BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    KEYWORDS  STRING512_D /* STRING512_D = VARCHAR(512) */
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_TOWARY ADD CONSTRAINT WWW_TOWARY_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_TOWARY_NAZWA_IND ON WWW_TOWARY (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_TOWARY TO WWW_ROLE;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_UWAGI_ID_GEN;

CREATE TABLE WWW_UWAGI (
    ID        INTEGER NOT NULL,
    PODPIS    VARCHAR(50),
    EMAIL     VARCHAR(64),
    TRESC     BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    ADRES_IP  ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    LINK      VARCHAR(128),
    DATA      DATE
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_UWAGI ADD CONSTRAINT WWW_UWAGI_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_UWAGI_ADRES_IP_IND ON WWW_UWAGI (ADRES_IP);
CREATE INDEX WWW_UWAGI_DATA_IND ON WWW_UWAGI (DATA);
CREATE INDEX WWW_UWAGI_EMAIL_IND ON WWW_UWAGI (EMAIL);
CREATE INDEX WWW_UWAGI_LINK_IND ON WWW_UWAGI (LINK);
CREATE INDEX WWW_UWAGI_PODPIS_IND ON WWW_UWAGI (PODPIS);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_UWAGI_BI */
CREATE TRIGGER WWW_UWAGI_BI FOR WWW_UWAGI
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_UWAGI_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_UWAGI TO WWW_ROLE;





/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_ZK (
    ID               INTEGER NOT NULL,
    USER_ID          INTEGER,
    PLATNOSC_TYP     INTEGER NOT NULL,
    PLATNOSC_KANAL   VARCHAR(4),
    PLATNOSC_STATUS  INTEGER,
    PAYBACK_LOGIN    VARCHAR(64),
    ADRES_IP         ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    TASK_ID          INTEGER,
    ALARM_ID         INTEGER,
    PLATNOSC_DATA    TIMESTAMP,
    PLATNOSC_INFO    BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    PLATNIK_ID       INTEGER,
    ODBIORCA_ID      INTEGER,
    CONTACT_ID       INTEGER,
    WEJSCIE_ID       INTEGER,
    AUKCJA_UID       INTEGER,
    AUKCJA_NUMER     INTEGER,
    PARTNER_ID       INTEGER,
    TEL              STRING20_D /* STRING20_D = VARCHAR(20) */,
    EMAIL            ADRES_EMAIL_D /* ADRES_EMAIL_D = VARCHAR(64) */
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_ALARM_ID_FK FOREIGN KEY (ALARM_ID) REFERENCES R3_ALARMY (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_CONTACT_ID_FK FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS (ID) ON DELETE SET NULL ON UPDATE SET NULL;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_ID_FK FOREIGN KEY (ID) REFERENCES GM_ZK (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_ODBIORCA_ID_FK FOREIGN KEY (ODBIORCA_ID) REFERENCES R3_CONTACTS (ID) ON DELETE SET NULL ON UPDATE SET NULL;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_PLATNIK_ID_FK FOREIGN KEY (PLATNIK_ID) REFERENCES R3_CONTACTS (ID) ON DELETE SET NULL ON UPDATE SET NULL;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_TASK_ID_FK FOREIGN KEY (TASK_ID) REFERENCES CRM_TASKS (ID) ON DELETE SET NULL ON UPDATE SET NULL
  USING INDEX WWW_ZK_TASK_ID_IND;
ALTER TABLE WWW_ZK ADD CONSTRAINT WWW_ZK_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE SET NULL ON UPDATE SET NULL
  USING INDEX WWW_ZK_USER_ID_IND;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ZK_AUKCJA_IND ON WWW_ZK (AUKCJA_NUMER, AUKCJA_UID);
CREATE UNIQUE INDEX WWW_ZK_ID_UNQ ON WWW_ZK (ID);
CREATE INDEX WWW_ZK_USER_ID ON WWW_ZK (USER_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZK TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_ZK_FS2PA (
    ZK_ID        INTEGER NOT NULL,
    ID_PLATNIKA  INTEGER NOT NULL,
    ID_ODBIORCY  INTEGER NOT NULL,
    CDATE        TIMESTAMP DEFAULT current_timestamp NOT NULL
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZK_FS2PA ADD CONSTRAINT WWW_ZK_FS2PA_PK PRIMARY KEY (ZK_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZK_FS2PA TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_ZT_ID_GEN;

CREATE TABLE WWW_ZT (
    ID                       ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    MAGNUM                   ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    SPOSOB_LICZENIA          BLOKADA_D NOT NULL /* BLOKADA_D = SMALLINT DEFAULT 0 CHECK (VALUE>=0 AND VALUE<=255) */,
    ID_SPOSOBU_PLATNOSCI     SLOWNIK_D NOT NULL /* SLOWNIK_D = INTEGER */,
    NAZWA_SPOSOBU_PLATNOSCI  STRING100_D NOT NULL /* STRING100_D = VARCHAR(100) */,
    TERMIN_PLATNOSCI         SMALLINT,
    SP_DOST_USLUGA           INTEGER,
    NAZWA_SPOSOBU_DOSTAWY    STRING100_D COLLATE PXW_PLK /* STRING100_D = VARCHAR(100) */,
    RODZAJ_CENY              SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    RODZAJ_RABATU            SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_WALUTY                ID_D DEFAULT 0 NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ID_TABELI_KURSOWEJ       SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    NUMER_TABELI_KURSOWEJ    NUMER_NULL_D /* NUMER_NULL_D = VARCHAR(20) */,
    KURS                     NUMERIC(15,8) DEFAULT 1,
    ID_PLATNIKA              ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ID_ODBIORCY              ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    NAZWA_SKROCONA_PLATNIKA  STRING50_D NOT NULL /* STRING50_D = VARCHAR(50) */,
    NIP_PLATNIKA             STRING20_D /* STRING20_D = VARCHAR(20) */,
    KOD_KRESKOWY_PLATNIKA    STRING40_D /* STRING40_D = VARCHAR(40) */,
    NAZWA_PELNA_PLATNIKA     NAZWA_D NOT NULL /* NAZWA_D = VARCHAR(250) NOT NULL */,
    ULICA_PLATNIKA           STRING50_D /* STRING50_D = VARCHAR(50) */,
    NRDOMU_PLATNIKA          STRING10_D /* STRING10_D = VARCHAR(10) */,
    NRLOKALU_PLATNIKA        STRING10_D /* STRING10_D = VARCHAR(10) */,
    KOD_PLATNIKA             STRING10_D /* STRING10_D = VARCHAR(10) */,
    MIEJSCOWOSC_PLATNIKA     STRING50_D /* STRING50_D = VARCHAR(50) */,
    PANSTWO_PLATNIKA         STRING25_D /* STRING25_D = VARCHAR(25) */,
    NAZWA_SKROCONA_ODBIORCY  STRING50_D NOT NULL /* STRING50_D = VARCHAR(50) */,
    NIP_ODBIORCY             STRING20_D /* STRING20_D = VARCHAR(20) */,
    KOD_KRESKOWY_ODBIORCY    STRING40_D /* STRING40_D = VARCHAR(40) */,
    NAZWA_PELNA_ODBIORCY     NAZWA_D NOT NULL /* NAZWA_D = VARCHAR(250) NOT NULL */,
    ULICA_ODBIORCY           STRING50_D /* STRING50_D = VARCHAR(50) */,
    NRDOMU_ODBIORCY          STRING10_D /* STRING10_D = VARCHAR(10) */,
    NRLOKALU_ODBIORCY        STRING10_D /* STRING10_D = VARCHAR(10) */,
    KOD_ODBIORCY             STRING10_D /* STRING10_D = VARCHAR(10) */,
    MIEJSCOWOSC_ODBIORCY     STRING50_D /* STRING50_D = VARCHAR(50) */,
    PANSTWO_ODBIORCY         STRING25_D /* STRING25_D = VARCHAR(25) */,
    WAL_WARTOSC_NETTO        WARTOSC_D DEFAULT 0 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    WAL_KWOTA_VAT            WARTOSC_D DEFAULT 0 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    WAL_WARTOSC_BRUTTO       WARTOSC_D DEFAULT 0 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    PLN_WARTOSC_NETTO        WARTOSC_D DEFAULT 0 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    PLN_KWOTA_VAT            WARTOSC_D DEFAULT 0.0000 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    PLN_WARTOSC_BRUTTO       WARTOSC_D DEFAULT 0.0000 NOT NULL /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    KOSZT_PRZESYLKI          CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    KOSZT_PRZESYLKI_BRUTTO   CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    DATADODANIA              DATA_TIME_D DEFAULT CURRENT_DATE NOT NULL /* DATA_TIME_D = TIMESTAMP */,
    GUID                     GUID_D /* GUID_D = CHAR(36) */,

    UWAGI                    BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    UWAGI_KLIENTA            BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    ADRES_WYSYLKI            BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    FV_DANE                  BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    CONFIRM                  BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CONFIRM_DATE             TIMESTAMP,
    EMAIL                    ADRES_EMAIL_D /* ADRES_EMAIL_D = VARCHAR(64) */,
    FAKTURA                  BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    USER_ID                  INTEGER,
    WEJSCIE_ID               INTEGER
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_ID_ODBIORCY_FK FOREIGN KEY (ID_ODBIORCY) REFERENCES R3_CONTACTS (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_ID_PLATNIKA_FK FOREIGN KEY (ID_PLATNIKA) REFERENCES R3_CONTACTS (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_ID_SP_ZAPLATY_FK FOREIGN KEY (ID_SPOSOBU_PLATNOSCI) REFERENCES GM_SPOSOBY_ZAP (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_MAGNUM_FK FOREIGN KEY (MAGNUM) REFERENCES GM_MAGAZYNY (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_RODZAJ_CENY_FK FOREIGN KEY (RODZAJ_CENY) REFERENCES GM_CENY (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT ADD CONSTRAINT WWW_ZT_RODZAJ_RABATU_FK FOREIGN KEY (RODZAJ_RABATU) REFERENCES GM_RABATY (ID) ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ZT_GUID_IND ON WWW_ZT (GUID);
CREATE INDEX WWW_ZT_ID_PLATNIKA_IND ON WWW_ZT (ID_PLATNIKA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_ZT_BI */
CREATE TRIGGER WWW_ZT_BI FOR WWW_ZT
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_ZT_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                             Descriptions                             ****/
/******************************************************************************/

DESCRIBE TABLE WWW_ZT
'Tabela zawiera dane nagwkowe zamwie tymczasowych do odbiorcw (ZO)';



/* Fields descriptions */

DESCRIBE FIELD ID TABLE WWW_ZT
'Identyfikator rekordu';

DESCRIBE FIELD MAGNUM TABLE WWW_ZT
'Identyfikator magazynu, w ktrym dokument zosta wystawiony';

DESCRIBE FIELD SPOSOB_LICZENIA TABLE WWW_ZT
'Sposb liczenia kwoty podatku VAT
0 - dokument liczony od netto
1 - od bruto
2 - od sumy';

DESCRIBE FIELD ID_SPOSOBU_PLATNOSCI TABLE WWW_ZT
'Domylny sposb patnoci';

DESCRIBE FIELD NAZWA_SPOSOBU_PLATNOSCI TABLE WWW_ZT
'Nazwa domylnego sposobu patnoci';

DESCRIBE FIELD RODZAJ_CENY TABLE WWW_ZT
'Identyfikator domylnego rodzaju ceny sprzeday';

DESCRIBE FIELD RODZAJ_RABATU TABLE WWW_ZT
'Identyfikator domylnego rodzaju rabatu';

DESCRIBE FIELD ID_WALUTY TABLE WWW_ZT
'Identyfikator waluty dokumentu';

DESCRIBE FIELD ID_TABELI_KURSOWEJ TABLE WWW_ZT
'Identyfikator tabeli kursowej przypisanej do dokumentu';

DESCRIBE FIELD NUMER_TABELI_KURSOWEJ TABLE WWW_ZT
'Sformatowany numer tabeli kursowej przypisanej do dokumentu';

DESCRIBE FIELD KURS TABLE WWW_ZT
'Kurs waluty dokumentu w PLN';

DESCRIBE FIELD ID_PLATNIKA TABLE WWW_ZT
'Identyfikator konrahenta patnika';

DESCRIBE FIELD ID_ODBIORCY TABLE WWW_ZT
'Identyfikator konrahenta odbiorcy';

DESCRIBE FIELD NAZWA_SKROCONA_PLATNIKA TABLE WWW_ZT
'Nazwa skrcona kontrahenta patnika';

DESCRIBE FIELD NIP_PLATNIKA TABLE WWW_ZT
'Numer NIP konrahenta patnika';

DESCRIBE FIELD KOD_KRESKOWY_PLATNIKA TABLE WWW_ZT
'Kod kreskowy kontrahenta patnika';

DESCRIBE FIELD NAZWA_PELNA_PLATNIKA TABLE WWW_ZT
'Pena nazwa kontrahenta patnika';

DESCRIBE FIELD ULICA_PLATNIKA TABLE WWW_ZT
'Nazwa ulicy kontrahenta patnika';

DESCRIBE FIELD NRDOMU_PLATNIKA TABLE WWW_ZT
'Numer domu kontrahenta patnika';

DESCRIBE FIELD NRLOKALU_PLATNIKA TABLE WWW_ZT
'Numer lokalu konrahenta patnika';

DESCRIBE FIELD KOD_PLATNIKA TABLE WWW_ZT
'Kod pocztowy kontrahenta paatnika';

DESCRIBE FIELD MIEJSCOWOSC_PLATNIKA TABLE WWW_ZT
'Nazwa miasta konrahenta patnika';

DESCRIBE FIELD PANSTWO_PLATNIKA TABLE WWW_ZT
'Nazwa pastwa kontahenta patnika';

DESCRIBE FIELD NAZWA_SKROCONA_ODBIORCY TABLE WWW_ZT
'Nazwa skrcona konrahenta odbiorcy';

DESCRIBE FIELD NIP_ODBIORCY TABLE WWW_ZT
'Numer NIP konrahenta odbiorcy';

DESCRIBE FIELD KOD_KRESKOWY_ODBIORCY TABLE WWW_ZT
'Kod kreskowy kontrahenta odbiorcy';

DESCRIBE FIELD NAZWA_PELNA_ODBIORCY TABLE WWW_ZT
'Nazwa pena kontrahenta odbiorcy';

DESCRIBE FIELD ULICA_ODBIORCY TABLE WWW_ZT
'Nazwa ulicy kontrahenta odbiorcy';

DESCRIBE FIELD NRDOMU_ODBIORCY TABLE WWW_ZT
'Numer domu kontrahenta odbiorcy';

DESCRIBE FIELD NRLOKALU_ODBIORCY TABLE WWW_ZT
'Numer lokalu kontrahenta odbiorcy';

DESCRIBE FIELD KOD_ODBIORCY TABLE WWW_ZT
'Kod pocztowy kontrahenta odbiorcy';

DESCRIBE FIELD MIEJSCOWOSC_ODBIORCY TABLE WWW_ZT
'Nazwa miasta kontrahenta odbiorcy';

DESCRIBE FIELD PANSTWO_ODBIORCY TABLE WWW_ZT
'Nazwa pastwa kontrahenta odbiorcy';

DESCRIBE FIELD WAL_WARTOSC_NETTO TABLE WWW_ZT
'Warto netto w walucie dokumentu';

DESCRIBE FIELD WAL_KWOTA_VAT TABLE WWW_ZT
'Kwota VAT w walucie dokumentu';

DESCRIBE FIELD WAL_WARTOSC_BRUTTO TABLE WWW_ZT
'Warto brutto w walucie dokumentu ';

DESCRIBE FIELD PLN_WARTOSC_NETTO TABLE WWW_ZT
'Warto dokumentu netto w PLN';

DESCRIBE FIELD DATADODANIA TABLE WWW_ZT
'Skrcona nazwa uytkownika, ktry zarejestrowa rekord';

DESCRIBE FIELD GUID TABLE WWW_ZT
'Specjalny identyfikator typu guid wykorzystywany do potwierdzenia zamwien';

DESCRIBE FIELD ADRES_WYSYLKI TABLE WWW_ZT
'Adres na jaki naley wysa zamwione towary.';

DESCRIBE FIELD CONFIRM TABLE WWW_ZT
'Czy zamwienie zostao potwierdzone';

DESCRIBE FIELD CONFIRM_DATE TABLE WWW_ZT
'Data potwierdzenia zamwienia';

DESCRIBE FIELD FAKTURA TABLE WWW_ZT
'Czy klient yczy sobie wystawi faktur vat za zamwione towary';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZT TO WWW_ROLE WITH GRANT OPTION;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_ZT_POZ_ID_GEN;

CREATE TABLE WWW_ZT_POZ (
    ID                          ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ID_GLOWKI                   ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ID_TOWARU                   ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    LP                          INTEGER,
    SKROT_ORYGINALNY            STRING25_D NOT NULL /* STRING25_D = VARCHAR(25) */,
    NAZWA_ORYGINALNA            STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    SKROT_ALTERNATYWNY          STRING25_D NOT NULL /* STRING25_D = VARCHAR(25) */,
    NAZWA_ALTERNATYWNA          STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    ILOSC_PO                    ILOSC_D NOT NULL /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    ID_OPAKOWANIA               SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ILOSC_ZAMOWIONYCH_OPAKOWAN  ILOSC_NULL_D /* ILOSC_NULL_D = NUMERIC(15,4) DEFAULT 0 CHECK  (VALUE >=0 OR VALUE IS NULL) */,
    JEDNOSTKA                   SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    JEDNOSTKA_ALT               SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    WSPOLCZYNNIK_JEDN           CENA_D DEFAULT 1 /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    ILOSC_ALT_PO                ILOSC_D /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    RODZAJ_RABATU               SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    RABAT                       PROCENT_D NOT NULL /* PROCENT_D = NUMERIC(6,2) DEFAULT 0 CHECK  ((VALUE >=0) OR (VALUE IS NULL)) */,
    ID_STAWKI                   ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    STAWKA                      PROCENT_D NOT NULL /* PROCENT_D = NUMERIC(6,2) DEFAULT 0 CHECK  ((VALUE >=0) OR (VALUE IS NULL)) */,
    RODZAJ_CENY                 SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_WAL_CENY_KAT             ID_D DEFAULT 0 NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    KURS_WAL_CENY_KAT           NUMERIC(15,8) DEFAULT 0,
    CENA_KATALOGOWA             CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SPRZEDAZY              CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_WAL_BRUTTO          CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_WAL_NETTO           CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_PLN_NETTO           CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_PLN_BRUTTO          CENA_D DEFAULT 0.0000 NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_WAL_NETTO_ALT       CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_WAL_BRUTTO_ALT      CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_PLN_NETTO_ALT       CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    CENA_SP_PLN_BRUTTO_ALT      CENA_D DEFAULT 0.0000 NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    WAGA_ZAMOWIONYCH_NETTO      ILOSC_D /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    WAGA_ZAMOWIONYCH_BRUTTO     ILOSC_D /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    WAGA_ZAMOWIONYCH_OPAKOWAN   ILOSC_D /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    UWAGI                       BLOB SUB_TYPE 0 SEGMENT SIZE 80,
    TYP_TOWARU                  STRING15_D COLLATE PXW_PLK /* STRING15_D = VARCHAR(15) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_ID_OPAKOWANIA_FK FOREIGN KEY (ID_OPAKOWANIA) REFERENCES GM_OPAKOWANIA (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_ID_TOWARU FOREIGN KEY (ID_TOWARU) REFERENCES GM_TOWARY (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_JEDN_ALT_FK FOREIGN KEY (JEDNOSTKA_ALT) REFERENCES GM_MIARY (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_RODZAJCENY_FK FOREIGN KEY (RODZAJ_CENY) REFERENCES GM_CENY (ID) ON UPDATE CASCADE;
ALTER TABLE WWW_ZT_POZ ADD CONSTRAINT WWW_ZT_POZ_RODZAJRABATU_FK FOREIGN KEY (RODZAJ_RABATU) REFERENCES GM_RABATY (ID) ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ZT_POZ_ID_GLOWKI_IND ON WWW_ZT_POZ (ID_GLOWKI);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_ZT_POZ_BI */
CREATE TRIGGER WWW_ZT_POZ_BI FOR WWW_ZT_POZ
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_ZT_POZ_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZT_POZ TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_IP_ID_GEN;

CREATE TABLE WWW_IP (
    ID            INTEGER NOT NULL,
    ADRES_IP      ADRES_IP_D NOT NULL /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    ADMIN_DOSTEP  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    WWW_BLOKADA   BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE         TIMESTAMP,
    MDATE         TIMESTAMP
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_IP ADD CONSTRAINT WWW_IP_ADRES_IP_UNQ UNIQUE (ADRES_IP)
USING INDEX WWW_IP_ADRES_IP_IND;


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_IP ADD CONSTRAINT WWW_IP_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_IP_BI */
CREATE TRIGGER WWW_IP_BI FOR WWW_IP
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_IP_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD ADRES_IP TABLE WWW_IP 'Pole dla adresu IP';

DESCRIBE FIELD ADMIN_DOSTEP TABLE WWW_IP 'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';

DESCRIBE FIELD WWW_BLOKADA TABLE WWW_IP 'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT SELECT, INSERT, UPDATE, DELETE ON WWW_IP TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE GENERATOR WWW_STRONY_ID_GEN;

CREATE TABLE WWW_STRONY (
    ID          INTEGER NOT NULL,
    NAZWA       VARCHAR(128) NOT NULL,
    TYTUL       STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    TRESC       BLOB SUB_TYPE 1 SEGMENT SIZE 2048,
    CDATE       TIMESTAMP NOT NULL,
    MDATE       TIMESTAMP NOT NULL,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_STRONY ADD CONSTRAINT WWW_STRONY_NAZWA_UNQ UNIQUE (NAZWA, INSTALACJA);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_STRONY ADD CONSTRAINT WWW_STRONY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_STRONY_DATY_IND ON WWW_STRONY (CDATE, MDATE);
CREATE INDEX WWW_STRONY_INSTALACJA_IND ON WWW_STRONY (INSTALACJA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_STRONY_BI */
CREATE TRIGGER WWW_STRONY_BI FOR WWW_STRONY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_STRONY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_STRONY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_HIST_LOGOWANIA_ID_GEN;

CREATE TABLE WWW_HIST_LOGOWANIA (
    ID                INTEGER NOT NULL,
    USER_ID           INTEGER NOT NULL,
    ADRES_IP          ADRES_IP_D NOT NULL /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    NAZWA_HOSTA       VARCHAR(250) NOT NULL,
    CZAS_LOGOWANIA    TIMESTAMP NOT NULL,
    CZAS_WYLOGOWANIA  TIMESTAMP DEFAULT NULL,
    BLAD              BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    BLEDNE_HASLO      VARCHAR(30) COLLATE PXW_PLK
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_HIST_LOGOWANIA ADD CONSTRAINT WWW_HIST_LOGOWANIA_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_HIST_LOGOWANIA ADD CONSTRAINT WWW_HIST_LOGOWANIA_USER_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_HIST_LOGOWANIA_CZASY_IND ON WWW_HIST_LOGOWANIA (CZAS_LOGOWANIA, CZAS_WYLOGOWANIA, BLAD);
CREATE INDEX WWW_HIST_LOGOWANIA_HOST_IND ON WWW_HIST_LOGOWANIA (NAZWA_HOSTA);
CREATE INDEX WWW_HIST_LOGOWANIA_IP_IND ON WWW_HIST_LOGOWANIA (ADRES_IP);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_HIST_LOGOWANIA_BI */
CREATE TRIGGER WWW_HIST_LOGOWANIA_BI FOR WWW_HIST_LOGOWANIA
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_HIST_LOGOWANIA_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD BLAD TABLE WWW_HIST_LOGOWANIA
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT SELECT, INSERT, UPDATE, DELETE ON WWW_HIST_LOGOWANIA TO WWW_ROLE;



/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/



SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_ONLINE_AD0 */
CREATE TRIGGER WWW_ONLINE_AD0 FOR WWW_ONLINE
ACTIVE AFTER DELETE POSITION 0
AS
declare variable HIST_LOG_ID Integer;
begin
  /* Trigger text */
  if (OLD.USER_ID > 0 ) then begin
        UPDATE WWW_HIST_LOGOWANIA SET CZAS_WYLOGOWANIA = OLD.LAST_ACTIVE WHERE USER_ID = OLD.USER_ID AND BLAD = 0 AND CZAS_WYLOGOWANIA IS NULL ;
  end
end
^


SET TERM ; ^




















/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE DOMAIN SMS_TRESC_D AS VARCHAR(640) CHARACTER SET WIN1250 COLLATE WIN1250;

CREATE GENERATOR WWW_SMS_LOG_ID_GEN;

CREATE TABLE WWW_SMS_LOG (
    ID        INTEGER NOT NULL,
    MODUL     VARCHAR(128),
    NUMER     STRING20_D /* STRING20_D = VARCHAR(20) */,
    TRESC     SMS_TRESC_D /* SMS_TRESC_D = VARCHAR(640) */,
    WYNIK     BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    CDATE     TIMESTAMP,
    ADRES_IP  ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SMS_LOG ADD CONSTRAINT WWW_SMS_LOG_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SMS_LOG_BI */
CREATE TRIGGER WWW_SMS_LOG_BI FOR WWW_SMS_LOG
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SMS_LOG_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SMS_LOG TO WWW_ROLE;



INSERT INTO WWW_SPOSOBY_DOSTAWY (ID,NAZWA,USLUGA,DOMYSLNY,WYSWIETLAJ,OPIS) VALUES (NULL, 'Odbir Osobisty', NULL, 1, 1, '');




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE GENERATOR WWW_NEWS_ID_GEN;

CREATE TABLE WWW_NEWS (
    ID          INTEGER NOT NULL,
    TYTUL       VARCHAR(250) NOT NULL,
    WYSWIETL    BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    DATA_DO     DATE,
    DATA_OD     DATE,
    WSTEP       BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    TRESC       BLOB SUB_TYPE 1 SEGMENT SIZE 1024,
    CDATE       TIMESTAMP NOT NULL,
    MDATE       TIMESTAMP NOT NULL,
    INSTALACJA  WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_NEWS ADD CONSTRAINT WWW_NEWS_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_NEWS_DATY_IND ON WWW_NEWS (CDATE, MDATE);
CREATE INDEX WWW_NEWS_INSTALACJA_IND ON WWW_NEWS (INSTALACJA);
CREATE INDEX WWW_NEWS_SERACH_IND ON WWW_NEWS (WYSWIETL, DATA_DO, DATA_OD);
CREATE INDEX WWW_NEWS_TYTUL_IND ON WWW_NEWS (TYTUL);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_NEWS_BI */
CREATE TRIGGER WWW_NEWS_BI FOR WWW_NEWS
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_NEWS_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD WYSWIETL TABLE WWW_NEWS
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_NEWS TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAM_GRUPY_ID_GEN;

CREATE TABLE WWW_PARAM_GRUPY (
    ID     INTEGER NOT NULL,
    NAZWA  STRING60_D /* STRING60_D = VARCHAR(60) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAM_GRUPY ADD CONSTRAINT WWW_PARAM_GRUPY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAM_GRUPY_BI */
CREATE TRIGGER WWW_PARAM_GRUPY_BI FOR WWW_PARAM_GRUPY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAM_GRUPY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAM_GRUPY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAMETRY_ID_GEN;

CREATE TABLE WWW_PARAMETRY (
    ID        INTEGER NOT NULL,
    GRUPA_ID  INTEGER,
    NAZWA     STRING200_D /* STRING200_D = VARCHAR(200) */,
    UKRYJ     BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    TYP       SMALLINT,
    LP        SMALLINT,
    CDATE     DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    MDATE     DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAMETRY ADD CONSTRAINT WWW_PARAMETRY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAMETRY_BI */
CREATE TRIGGER WWW_PARAMETRY_BI FOR WWW_PARAMETRY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAMETRY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD CDATE TABLE WWW_PARAMETRY
'Wzorzec dla pl zawierajcych dat i czas';

DESCRIBE FIELD MDATE TABLE WWW_PARAMETRY
'Wzorzec dla pl zawierajcych dat i czas';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAMETRY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAM_WART_ID_GEN;

CREATE TABLE WWW_PARAM_WART (
    ID        INTEGER NOT NULL,
    PARAM_ID  INTEGER DEFAULT 0,
    WARTOSC   STRING200_D NOT NULL COLLATE PXW_PLK /* STRING200_D = VARCHAR(200) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAM_WART ADD CONSTRAINT WWW_PARAM_WART_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAM_WART_BI */
CREATE TRIGGER WWW_PARAM_WART_BI FOR WWW_PARAM_WART
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAM_WART_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAM_WART TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_TOWARY_PARAMS (
    TOWAR_ID  INTEGER NOT NULL,
    PARAM_ID  INTEGER NOT NULL,
    WART_ID   INTEGER NOT NULL,
    LP        SMALLINT
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_UNQ UNIQUE (TOWAR_ID, PARAM_ID, WART_ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_PARAM_FK FOREIGN KEY (PARAM_ID) REFERENCES WWW_PARAMETRY (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_TOWAR_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_TOWARY_PARAMS_PWART_IND ON WWW_TOWARY_PARAMS (WART_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_TOWARY_PARAMS TO WWW_ROLE;





/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE TABLE WWW_GRUPYT_SERWISY (
    GRUPA_ID      INTEGER NOT NULL,
    EXT           BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    SERWIS        VARCHAR(32) NOT NULL,
    SERWIS_GRUPA  INTEGER NOT NULL
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT_SERWISY ADD CONSTRAINT WWW_GRUPYT_SERWISY_UNQ UNIQUE (GRUPA_ID, EXT, SERWIS);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_GRUPYT_SERWISY_GRUPA_IND ON WWW_GRUPYT_SERWISY (GRUPA_ID, EXT);
CREATE INDEX WWW_GRUPYT_SERWISY_SERWIS_IND ON WWW_GRUPYT_SERWISY (SERWIS, SERWIS_GRUPA);


/* Fields descriptions */

DESCRIBE FIELD EXT TABLE WWW_GRUPYT_SERWISY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_GRUPYT_SERWISY TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_OFERTY_ID_GEN;

CREATE TABLE WWW_OFERTY (
    ID            INTEGER NOT NULL,
    FORMAT        STRING20_D COLLATE PXW_PLK /* STRING20_D = VARCHAR(20) */,
    NAZWA         VARCHAR(128) NOT NULL,
    KODOWANIE     STRING20_D NOT NULL COLLATE PXW_PLK /* STRING20_D = VARCHAR(20) */,
    BRANZA        STRING30_D NOT NULL /* STRING30_D = VARCHAR(30) */,
    RODZAJ        STRING10_D NOT NULL /* STRING10_D = VARCHAR(10) */,
    CENA_ID       INTEGER,
    USE_CACHE     BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CACHE_PERIOD  INTEGER,
    GRUPA_ID      INTEGER,
    CENNIKI       BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    ATRYBUTY      BLOB SUB_TYPE 1 SEGMENT SIZE 512 NOT NULL,
    DANE          BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    UWAGI         VARCHAR(512),
    CDATE         TIMESTAMP NOT NULL,
    MDATE         TIMESTAMP NOT NULL,
    DOSTEPNOSC    SMALLINT,
    STAN_TOWARU   SMALLINT,
    MAGAZYNY      BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    REQ_PARAM     INTEGER
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_CENA_ID_FK FOREIGN KEY (CENA_ID) REFERENCES GM_CENY (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_REQ_PARAM_FK FOREIGN KEY (REQ_PARAM) REFERENCES WWW_PARAMETRY (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_OFERTY_DATY_IND ON WWW_OFERTY (CDATE, MDATE);
CREATE UNIQUE INDEX WWW_OFERTY_NAZWA_IND ON WWW_OFERTY (FORMAT, NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_OFERTY_BI */
CREATE TRIGGER WWW_OFERTY_BI FOR WWW_OFERTY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_OFERTY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD USE_CACHE TABLE WWW_OFERTY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_OFERTY TO WWW_ROLE;



/******************************************************************************/

ALTER TABLE WWW_STATS DROP CONSTRAINT WWW_STATS_TOWAR_ID_FK;
ALTER TABLE WWW_STATS ADD CONSTRAINT WWW_STATS_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY(ID) ON DELETE CASCADE ON UPDATE CASCADE;

--ALTER TABLE WWW_GRUPYT_EXT DROP RADAR_ID;
--ALTER TABLE WWW_GRUPYT DROP RADAR_ID;

update RDB$RELATION_FIELDS set RDB$FIELD_SOURCE = 'STRING200_D' where (RDB$FIELD_NAME = 'FIRMA_NAZWA') and (RDB$RELATION_NAME = 'WWW_REG');


/**************************************************************************************************/

CREATE DOMAIN WWW_SESJA_D AS CHAR(32) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250;
CREATE DOMAIN WWW_IDENT_D AS VARCHAR(15) CHARACTER SET WIN1250 COLLATE PXW_PLK;
CREATE DOMAIN ALLEGRO_LOGIN_D AS VARCHAR(16) CHARACTER SET WIN1250 COLLATE WIN1250;




CREATE GENERATOR WWW_AUKCJE_ID_GEN;


CREATE TABLE WWW_AUKCJE (
    ID                  INTEGER NOT NULL,
    SERWIS              VARCHAR(32) NOT NULL,
    SELLER_ID           SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    SELLER_LOGIN        ALLEGRO_LOGIN_D COLLATE PXW_PLK /* ALLEGRO_LOGIN_D = VARCHAR(16) */,
    CAT_ID              INTEGER NOT NULL,
    ITEM_ID             INTEGER NOT NULL,
    TOWAR_ID            INTEGER,
    AUCTION_TYPE        STRING10_D NOT NULL /* STRING10_D = VARCHAR(10) */,
    ITEM_NAME           STRING50_D NOT NULL /* STRING50_D = VARCHAR(50) */,
    TOWAR_NAZWA         STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    STARTING_PRICE      CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    TPL                 VARCHAR(128),
    BUY_RESERVE_PRICE   CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    BUY_NOW_PRICE       CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    SELL_QUANTITY       ILOSC_D NOT NULL /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    QUANTITY_TYPE       SMALLINT,
    FUTURE_ACTIVE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    AUCTION_DURATION    SMALLINT,
    COUNTRY             INTEGER,
    STATE               SMALLINT,
    LOCATION            STRING200_D /* STRING200_D = VARCHAR(200) */,
    TRANSPORT           VARCHAR(8),
    TRANSPORT_SHIPMENT  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    WIRE_TRANSFER       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    POSTAGE_TRANSFER    BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    BOLD_TITLE          BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    LISTING_THUMB       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    HIGHLIGHT           BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    FEATURED            BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CATEGORY_PAGE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ITEM_PRICE          CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    STARTING_TIME       INTEGER,
    HIGH_BIDDER         INTEGER,
    IS_ECO              BOOLEAN_NULL_D /* BOOLEAN_NULL_D = SMALLINT CHECK ((VALUE IS NULL) OR (VALUE IN (0,1))) */,
    HIT_COUNT           INTEGER,
    CDATE               TIMESTAMP NOT NULL,
    MDATE               TIMESTAMP NOT NULL,
    ARCHIVE             BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    KILLED              BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ZK_POZ_ID           SLOWNIK_D /* SLOWNIK_D = INTEGER */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AUKCJE ADD CONSTRAINT WWW_AUKCJE_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AUKCJE ADD CONSTRAINT WWW_AUKCJE_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID) ON DELETE SET NULL ON UPDATE SET NULL;


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_AUKCJE_BI0 */
CREATE TRIGGER WWW_AUKCJE_BI0 FOR WWW_AUKCJE
ACTIVE BEFORE INSERT POSITION 0
AS
begin
  /* Trigger text */
 IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_AUKCJE_ID_GEN,1);
end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_AUKCJE TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_AU_BLOBS (
    AUKCJA_ID    INTEGER NOT NULL,
    DESCRIPTION  BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    FIELDS       BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    ATTRIBS      BLOB SUB_TYPE 0 SEGMENT SIZE 256,
    FOTOS        BLOB SUB_TYPE 0 SEGMENT SIZE 256
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AU_BLOBS ADD CONSTRAINT WWW_AU_BLOBS_AUKCJA_ID_FK FOREIGN KEY (AUKCJA_ID) REFERENCES WWW_AUKCJE (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_AU_BLOBS TO WWW_ROLE;



CREATE TABLE WWW_AU_CATS (
    ID          INTEGER NOT NULL,
    PARENT_ID   INTEGER,
    SERWIS      INTEGER NOT NULL,
    "POSITION"  INTEGER NOT NULL,
    NAME        STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    SKLEP       BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AU_CATS ADD CONSTRAINT WWW_AU_CATS_PK PRIMARY KEY (ID, SERWIS);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_AU_CATS_PARENT_ID_IND ON WWW_AU_CATS (PARENT_ID);
CREATE INDEX WWW_AU_CATS_POSITION_IND ON WWW_AU_CATS ("POSITION");


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_AU_CATS TO WWW_ROLE;







CREATE GENERATOR WWW_CSV_ID_GEN;

CREATE TABLE WWW_CSV (
    ID                INTEGER NOT NULL,
    NAZWA             VARCHAR(128) NOT NULL,
    KODOWANIE         STRING30_D /* STRING30_D = VARCHAR(30) */,
    CENA_ID           INTEGER NOT NULL,
    CENNIKI           BLOB SUB_TYPE 0 SEGMENT SIZE 80,
    POLA              BLOB SUB_TYPE 0 SEGMENT SIZE 80,
    SEPARATOR_TEKSTU  CHAR_CODE_D NOT NULL /* CHAR_CODE_D = CHAR(1) NOT NULL */,
    SEPARATOR_POLA    CHAR_CODE_D NOT NULL /* CHAR_CODE_D = CHAR(1) NOT NULL */,
    USE_CACHE         BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CACHE_PERIOD      INTEGER,
    UWAGI             BLOB SUB_TYPE 0 SEGMENT SIZE 80,
    CDATE             TIMESTAMP,
    MDATE             TIMESTAMP
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_CSV ADD CONSTRAINT WWW_CSV_ID_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_CSV_DATY_IND ON WWW_CSV (CDATE, MDATE);
CREATE UNIQUE INDEX WWW_CSV_NAZWA_UNQ ON WWW_CSV (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_CSV TO WWW_ROLE;






/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_CENNIK_ID_GEN;

CREATE TABLE WWW_CENNIK (
    ID                    ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ID_KONTRAHENTA        SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_GRUPYK             SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_PRODUCENTA         SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_GRUPYT             SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_SPOSOBU_PLATNOSCI  SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ID_OPAKOWANIA         SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    INTERNET              BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    NEWSLETTER            BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    IDCENY                SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    RODZAJ_RABATU         SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    RABAT                 PROCENT_D DEFAULT 0 NOT NULL /* PROCENT_D = NUMERIC(6,2) DEFAULT 0 CHECK  ((VALUE >=0) OR (VALUE IS NULL)) */,
    OPERATOR              STRING15_D /* STRING15_D = VARCHAR(15) */,
    DATAREJ               DATA_TIME_D DEFAULT CURRENT_DATE NOT NULL /* DATA_TIME_D = TIMESTAMP */,
    ZMIENIL               STRING15_D /* STRING15_D = VARCHAR(15) */,
    DATAZMIANY            DATA_TIME_D DEFAULT CURRENT_DATE NOT NULL /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_IDCENY_FK FOREIGN KEY (IDCENY) REFERENCES GM_CENY (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_GRUPYK_FK FOREIGN KEY (ID_GRUPYK) REFERENCES R3_CONTACT_GROUPS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_GRUPYT_FK FOREIGN KEY (ID_GRUPYT) REFERENCES GM_GRUPYT (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_KONTRAHENTA_FK FOREIGN KEY (ID_KONTRAHENTA) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_OPAKOWANIA_FK FOREIGN KEY (ID_OPAKOWANIA) REFERENCES GM_OPAKOWANIA (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_PRODUCENTA_FK FOREIGN KEY (ID_PRODUCENTA) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_SP_PL_FK FOREIGN KEY (ID_SPOSOBU_PLATNOSCI) REFERENCES GM_SPOSOBY_ZAP (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_RODZ_RAB_FK FOREIGN KEY (RODZAJ_RABATU) REFERENCES GM_RABATY (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_CENNIK_DATY_IND ON WWW_CENNIK (DATAREJ, DATAZMIANY);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_CENNIK TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_ZAL_GRUPY_ID_GEN;

CREATE TABLE WWW_ZAL_GRUPY (
    ID                 INTEGER NOT NULL,
    NAZWA              STRING50_D NOT NULL /* STRING50_D = VARCHAR(50) */,
    WYSWIETLANIE       SMALLINT NOT NULL,
    CZAS_WYSWIETLANIA  NUMERIC(12,4),
    LICZBA_POBRAN      INTEGER,
    UWAGI              BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    CDATE              TIMESTAMP NOT NULL,
    MDATE              TIMESTAMP NOT NULL
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZAL_GRUPY ADD CONSTRAINT WWW_ZAL_GRUPY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE UNIQUE INDEX WWW_ZAL_GRUPY_NAZWA_IND ON WWW_ZAL_GRUPY (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZAL_GRUPY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_ZAL_POBRANIA (
    ZAL_ID   INTEGER NOT NULL,
    USER_ID  INTEGER,
    KIEDY    TIMESTAMP NOT NULL
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZAL_POBRANIA ADD CONSTRAINT WWW_ZAL_POBRANIA_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE SET NULL ON UPDATE SET NULL;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ZAL_POBRANIA_KIEDY_IND ON WWW_ZAL_POBRANIA (KIEDY);
CREATE INDEX WWW_ZAL_POBRANIA_ZAL_ID_IND ON WWW_ZAL_POBRANIA (ZAL_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_ZAL_POBRANIA TO WWW_ROLE;






/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_PROFILE_ID_GEN;

CREATE TABLE WWW_PROFILE (
    ID             INTEGER NOT NULL,
    NAZWA          STRING80_D NOT NULL /* STRING80_D = VARCHAR(80) */,
    MANAGER        BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    AKWIZYTORZY    BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    GRUPAK_ID      INTEGER,
    GRUPAK_EXT_ID  INTEGER,
    UWAGI          BLOB SUB_TYPE 1 SEGMENT SIZE 512,
    C_DATE         DATA_TIME_D NOT NULL /* DATA_TIME_D = TIMESTAMP */,
    M_DATE         DATA_TIME_D NOT NULL /* DATA_TIME_D = TIMESTAMP */,
    C_IDENT        WWW_IDENT_D NOT NULL /* WWW_IDENT_D = VARCHAR(15) */,
    M_IDENT        WWW_IDENT_D NOT NULL /* WWW_IDENT_D = VARCHAR(15) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_GRUPAK_EXT_ID_FK FOREIGN KEY (GRUPAK_EXT_ID) REFERENCES R3_CONTACT_EXT_GROUPS (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_GRUPAK_ID_FK FOREIGN KEY (GRUPAK_ID) REFERENCES R3_CONTACT_GROUPS (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_PROFILE_CMIDENT_IND ON WWW_PROFILE (C_IDENT, M_IDENT);
CREATE INDEX WWW_PROFILE_DATY_IND ON WWW_PROFILE (C_DATE, M_DATE);
CREATE UNIQUE INDEX WWW_PROFILE_NAZWA_IND ON WWW_PROFILE (NAZWA);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PROFILE TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_PRIVS (
    USER_ID    INTEGER,
    PROFIL_ID  INTEGER,
    DOC_ID     INTEGER,
    AKCJA      VARCHAR(16) NOT NULL,
    PRIVS      VARCHAR(8) NOT NULL,
    WIDOK      SMALLINT NOT NULL,
    C_DATE     DATA_TIME_D NOT NULL /* DATA_TIME_D = TIMESTAMP */,
    M_DATE     DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_UNQ UNIQUE (USER_ID, PROFIL_ID, DOC_ID, AKCJA);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_PROFIL_ID_FK FOREIGN KEY (PROFIL_ID) REFERENCES WWW_PROFILE (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_PRIVS_DATY_IND ON WWW_PRIVS (C_DATE, M_DATE);
CREATE INDEX WWW_PRIVS_DOC_ID_IND ON WWW_PRIVS (DOC_ID);
CREATE INDEX WWW_PRIVS_PRIVS_IND ON WWW_PRIVS (PRIVS);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PRIVS TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_CONTACTS (
    CONTACT_ID      INTEGER NOT NULL,
    ALLEGRO_UID     INTEGER,
    ALLEGRO_LOGIN   ALLEGRO_LOGIN_D /* ALLEGRO_LOGIN_D = VARCHAR(16) */,
    ALLEGRO_RATING  INTEGER
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_CONTACTS ADD CONSTRAINT WWW_CONTACTS_CONTACT_ID_FK FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_CONTACTS_ALLEGRO_LOGIN_IND ON WWW_CONTACTS (ALLEGRO_LOGIN);
CREATE INDEX WWW_CONTACTS_ALLEGRO_UID_IND ON WWW_CONTACTS (ALLEGRO_UID);
CREATE UNIQUE INDEX WWW_CONTACTS_CONTACT_ID ON WWW_CONTACTS (CONTACT_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_CONTACTS TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_WEJSCIA_ID_GEN;

CREATE TABLE WWW_WEJSCIA (
    ID            INTEGER NOT NULL,
    SESSION_ID    CHAR(32) NOT NULL,
    USER_ID       INTEGER,
    CONTACT_ID    INTEGER,
    HOST          VARCHAR(128),
    URL           STRING1024_D NOT NULL /* STRING1024_D = VARCHAR(1024) */,
    ADRES_IP      ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    PRZEGLADARKA  VARCHAR(200),
    CZAS_WEJSCIA  TIMESTAMP NOT NULL,
    ZK            BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    REQUEST_URL   STRING1024_D /* STRING1024_D = VARCHAR(1024) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_CONTACT_ID FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_WEJSCIA_ADRES_IP ON WWW_WEJSCIA (ADRES_IP);
CREATE INDEX WWW_WEJSCIA_CZAS_WEJSCIA_IND ON WWW_WEJSCIA (CZAS_WEJSCIA);
CREATE INDEX WWW_WEJSCIA_HOST_IND ON WWW_WEJSCIA (HOST, ZK);
CREATE INDEX WWW_WEJSCIA_PRZEGLDARKA_IND ON WWW_WEJSCIA (PRZEGLADARKA);
CREATE INDEX WWW_WEJSCIA_SESSION_ID_IND ON WWW_WEJSCIA (SESSION_ID);
CREATE INDEX WWW_WEJSCIA_ZK_IND ON WWW_WEJSCIA (ZK);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_WEJSCIA_AI0 */
CREATE TRIGGER WWW_WEJSCIA_AI0 FOR WWW_WEJSCIA
ACTIVE AFTER INSERT POSITION 0
AS
begin
  /* Trigger text */
  UPDATE WWW_ONLINE SET WEJSCIE_ID = NEW.ID WHERE SESSION_ID = NEW.SESSION_ID;
end
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD ZK TABLE WWW_WEJSCIA
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_WEJSCIA TO WWW_ROLE;





/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SONDA_ID_GEN;

CREATE TABLE WWW_SONDA (
    ID             INTEGER NOT NULL,
    PYTANIE        VARCHAR(512) NOT NULL COLLATE PXW_PLK,
    PUBLIKACJA_OD  DATE NOT NULL,
    PUBLIKACJA_DO  DATE,
    UWAGI          VARCHAR(512) COLLATE PXW_PLK
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA ADD CONSTRAINT WWW_SONDA_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SONDA_DATY_IND ON WWW_SONDA (PUBLIKACJA_OD, PUBLIKACJA_DO);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: ID_SONDY_TRIG */
CREATE TRIGGER ID_SONDY_TRIG FOR WWW_SONDA
ACTIVE BEFORE INSERT POSITION 0
AS
begin

  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SONDA_ID_GEN,1);

end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SONDA TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SONDA_ODPOWIEDZI_ID_GEN;

CREATE TABLE WWW_SONDA_ODPOWIEDZI (
    ID         INTEGER NOT NULL,
    ID_SONDY   INTEGER NOT NULL,
    ODPOWIEDZ  VARCHAR(512) NOT NULL COLLATE PXW_PLK,
    GLOSY      INTEGER DEFAULT          0 NOT NULL
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA_ODPOWIEDZI ADD CONSTRAINT WWW_SONDA_ODP_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA_ODPOWIEDZI ADD CONSTRAINT WWW_SONDA_ODP_ID_SONDY_FK FOREIGN KEY (ID_SONDY) REFERENCES WWW_SONDA (ID) ON DELETE CASCADE ON UPDATE CASCADE
  USING INDEX ODPOWIEDZI_ID_SONDY_FK;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SONDA_ODPOWIEDZI_GLOSY ON WWW_SONDA_ODPOWIEDZI (GLOSY);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SONDA_ODPOWIEDZI_BI0 */
CREATE TRIGGER WWW_SONDA_ODPOWIEDZI_BI0 FOR WWW_SONDA_ODPOWIEDZI
ACTIVE BEFORE INSERT POSITION 0
AS
begin

  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SONDA_ODPOWIEDZI_ID_GEN,1);

end
^


SET TERM ; ^



/* Fields descriptions */
DESCRIBE FIELD ID TABLE WWW_SONDA_ODPOWIEDZI
'identyfikator pytania';

DESCRIBE FIELD ID_SONDY TABLE WWW_SONDA_ODPOWIEDZI
'identyfikator sondy';

DESCRIBE FIELD ODPOWIEDZ TABLE WWW_SONDA_ODPOWIEDZI
'odpowiedz
';

DESCRIBE FIELD GLOSY TABLE WWW_SONDA_ODPOWIEDZI
'liczba glosow';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SONDA_ODPOWIEDZI TO WWW_ROLE;






/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_TEKSTY_ID_GEN;

CREATE TABLE WWW_TEKSTY (
    ID         INTEGER NOT NULL,
    NAZWA      STRING60_D NOT NULL /* STRING60_D = VARCHAR(60) */,
    TEKST      VARCHAR(2048) NOT NULL,
    OPIS       BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    SYSTEMOWY  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE      DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    MDATE      DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_TEKSTY ADD CONSTRAINT WWW_TEKSTY_NAZWA_UNQ UNIQUE (NAZWA);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_TEKSTY ADD CONSTRAINT PK_WWW_TEKSTY PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_TEKSTY_DATY_IND ON WWW_TEKSTY (CDATE, MDATE);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_TEKSTY_BI */
CREATE TRIGGER WWW_TEKSTY_BI FOR WWW_TEKSTY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_TEKSTY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD SYSTEMOWY TABLE WWW_TEKSTY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_TEKSTY TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_ZD (
    ID                       ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    USER_ID                  ID_D /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    DOSTAWCA_ID              ID_D /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    ADRES_IP                 ADRES_IP_D /* ADRES_IP_D = VARCHAR(15) DEFAULT '0.0.0.0' */,
    EMAIL                    ADRES_EMAIL_D /* ADRES_EMAIL_D = VARCHAR(64) */,
    TEL                      STRING20_D /* STRING20_D = VARCHAR(20) */,
    UWAGI_KLIENTA            BLOB SUB_TYPE 1 SEGMENT SIZE 80,
    ID_SPOSOBU_PLATNOSCI     SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    NAZWA_SPOSOBU_PLATNOSCI  STRING100_D COLLATE PXW_PLK /* STRING100_D = VARCHAR(100) */,
    DATA_PLATNOSCI           DATA_D /* DATA_D = DATE */,
    DOSTAWA_ID_ADRESU        SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    DOSTAWA_ULICA            STRING40_D COLLATE PXW_PLK /* STRING40_D = VARCHAR(40) */,
    DOSTAWA_NR_DOMU          STRING10_D COLLATE PXW_PLK /* STRING10_D = VARCHAR(10) */,
    DOSTAWA_NR_LOKALU        STRING10_D COLLATE PXW_PLK /* STRING10_D = VARCHAR(10) */,
    DOSTAWA_KOD_POCZTOWY     STRING10_D COLLATE PXW_PLK /* STRING10_D = VARCHAR(10) */,
    DOSTAWA_MIEJSCOWOSC      STRING40_D COLLATE PXW_PLK /* STRING40_D = VARCHAR(40) */,
    DOSTAWA_PANSTWO          STRING40_D COLLATE PXW_PLK /* STRING40_D = VARCHAR(40) */
);




/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_ZD ADD CONSTRAINT WWW_ZD_ADRES_DOSTAWY_ID_FK FOREIGN KEY (DOSTAWA_ID_ADRESU) REFERENCES R3_CONTACT_ADDRESSES (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_ZD ADD CONSTRAINT WWW_ZD_DOSTAWCA_ID_FK FOREIGN KEY (DOSTAWCA_ID) REFERENCES R3_CONTACTS (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_ZD ADD CONSTRAINT WWW_ZD_ID_FK FOREIGN KEY (ID) REFERENCES GM_ZD (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_ZD ADD CONSTRAINT WWW_ZD_ID_SPOSOBU_PLATNOSCI_FK FOREIGN KEY (ID_SPOSOBU_PLATNOSCI) REFERENCES GM_SPOSOBY_ZAP (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_ZD ADD CONSTRAINT WWW_ZD_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_ZD_ADRES_IP_IND ON WWW_ZD (ADRES_IP);
CREATE INDEX WWW_ZD_EMAIL_IND ON WWW_ZD (EMAIL);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/

/* Privileges of roles */
GRANT ALL ON WWW_ZD TO WWW_ROLE;

/**************************************************************************************************/



ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PROFIL_ID_FK FOREIGN KEY (PROFIL_ID) REFERENCES WWW_PROFILE(ID) ON DELETE SET NULL ON UPDATE CASCADE;



GRANT ALL ON WWW_AUKCJE TO WWW_ROLE;
GRANT ALL ON WWW_CENNIK TO WWW_ROLE;
GRANT ALL ON WWW_CONFIG TO WWW_ROLE;
GRANT ALL ON WWW_CONTACTS TO WWW_ROLE;
GRANT ALL ON WWW_CSV TO WWW_ROLE;
GRANT ALL ON WWW_DB_VERSION TO WWW_ROLE;
GRANT ALL ON WWW_ERRORS TO WWW_ROLE;
GRANT ALL ON WWW_FAV TO WWW_ROLE;
GRANT ALL ON WWW_FAV_POZ TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT_EXT TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT_SERWISY TO WWW_ROLE;
GRANT ALL ON WWW_HIST_LOGOWANIA TO WWW_ROLE;
GRANT ALL ON WWW_IP TO WWW_ROLE;
GRANT ALL ON WWW_KOMENTARZE TO WWW_ROLE;
GRANT ALL ON WWW_KOSZYK TO WWW_ROLE;
GRANT ALL ON WWW_KOSZYK_POZ TO WWW_ROLE;
GRANT ALL ON WWW_LOG TO WWW_ROLE;
GRANT ALL ON WWW_OFERTY TO WWW_ROLE;
GRANT ALL ON WWW_ONLINE TO WWW_ROLE;
GRANT ALL ON WWW_PARAMETRY TO WWW_ROLE;
GRANT ALL ON WWW_PARAM_GRUPY TO WWW_ROLE;
GRANT ALL ON WWW_PARAM_WART TO WWW_ROLE;
GRANT ALL ON WWW_POWIADOMIENIA TO WWW_ROLE;
GRANT ALL ON WWW_PRIVS TO WWW_ROLE;
GRANT ALL ON WWW_PROFILE TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI_KOSZTY TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI_OPCJE TO WWW_ROLE;
GRANT ALL ON WWW_REG TO WWW_ROLE;
GRANT ALL ON WWW_SEARCH_HISTORY TO WWW_ROLE;
GRANT ALL ON WWW_SMS_LOG TO WWW_ROLE;
GRANT ALL ON WWW_SPOSOBY_DOSTAWY TO WWW_ROLE;
GRANT ALL ON WWW_STANY_UMOWNE TO WWW_ROLE;
GRANT ALL ON WWW_STATS TO WWW_ROLE;
GRANT ALL ON WWW_STRONY TO WWW_ROLE;
GRANT ALL ON WWW_SYNONIMY TO WWW_ROLE;
GRANT ALL ON WWW_TOWARY TO WWW_ROLE;
GRANT ALL ON WWW_TOWARY_PARAMS TO WWW_ROLE;
GRANT ALL ON WWW_USERS TO WWW_ROLE;
GRANT ALL ON WWW_USERS_CONFIG TO WWW_ROLE;
GRANT ALL ON WWW_UWAGI TO WWW_ROLE;
GRANT ALL ON WWW_WEJSCIA TO WWW_ROLE;
GRANT ALL ON WWW_WYRAZY TO WWW_ROLE;
GRANT ALL ON WWW_ZAL_GRUPY TO WWW_ROLE;
GRANT ALL ON WWW_ZAL_POBRANIA TO WWW_ROLE;
GRANT ALL ON WWW_ZK TO WWW_ROLE;
GRANT ALL ON WWW_ZK_FS2PA TO WWW_ROLE;
GRANT ALL ON WWW_ZT TO WWW_ROLE;
GRANT ALL ON WWW_ZT_POZ TO WWW_ROLE;
GRANT ALL ON WWW_NEWS TO WWW_ROLE;
