
/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_TEKSTY_ID_GEN;

CREATE TABLE WWW_TEKSTY (
    ID         INTEGER NOT NULL,
    NAZWA      STRING60_D NOT NULL /* STRING60_D = VARCHAR(60) */,
    TEKST      VARCHAR(2048) NOT NULL,
    OPIS       BLOB SUB_TYPE 2 SEGMENT SIZE 256,
    SYSTEMOWY  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CDATE      DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    MDATE      DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_TEKSTY ADD CONSTRAINT WWW_TEKSTY_NAZWA_UNQ UNIQUE (NAZWA);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_TEKSTY ADD CONSTRAINT PK_WWW_TEKSTY PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_TEKSTY_DATY_IND ON WWW_TEKSTY (CDATE, MDATE);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_TEKSTY_BI */
CREATE TRIGGER WWW_TEKSTY_BI FOR WWW_TEKSTY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_TEKSTY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD SYSTEMOWY TABLE WWW_TEKSTY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_TEKSTY TO WWW_ROLE;
